CodecError

Enum CodecError 

pub enum CodecError {
    InvalidSchema(SchemaError),
    TableSchemaMustBeTuple {
        found: WireType,
    },
    Truncated {
        context: &'static str,
    },
    RowTooLarge {
        limit: usize,
    },
    BlobTooLarge {
        wire_type: WireType,
        length: usize,
        limit: usize,
    },
    ValueDoesNotMatchSchema {
        expected: WireType,
        actual: &'static str,
    },
    TupleLength {
        expected: usize,
        actual: usize,
    },
    InvalidVariantTag {
        wire_type: WireType,
        tag: u16,
        children: usize,
    },
    VariantTagTooWide {
        wire_type: WireType,
        tag: u16,
    },
    BlobLengthOverflowsU32 {
        wire_type: WireType,
        length: usize,
    },
    Write(Error),
    Read(Error),
}
A wire or I/O failure while encoding or decoding Skiff.

Variants



InvalidSchema(SchemaError)

A schema was invalid before a stream was touched.



TableSchemaMustBeTuple

A table format schema did not have the required tuple root.

Fields

found: WireType

The root wire type that was supplied.



Truncated

The stream ended after a row had started.

Fields

context: &'static str

The incomplete portion of the stream.



RowTooLarge

One row would decode into more memory than the configured limit.

Fields

limit: usize

The configured maximum decoded footprint of one row.



BlobTooLarge

A declared blob size would exceed the configured resource limit.

Fields

wire_type: WireType

The schema type that carried the length.

length: usize

The decoded or supplied payload size.

limit: usize

The configured maximum.



ValueDoesNotMatchSchema

An encoded value did not match its schema node.

Fields

expected: WireType

The schema’s requested wire type.

actual: &'static str

The supplied value’s stable kind.



TupleLength

A tuple carried a different number of values than its schema children.

Fields

expected: usize

The schema child count.

actual: usize

The supplied value count.



InvalidVariantTag

A variant tag did not select a child in its schema.

Fields

wire_type: WireType

The variant wire type.

tag: u16

The invalid tag.

children: usize

The schema child count.



VariantTagTooWide

A repeated-variant value carried a tag wider than the variant supports.

Fields

wire_type: WireType

The repeated-variant wire type.

tag: u16

The tag that did not fit.



BlobLengthOverflowsU32

A caller supplied a payload that cannot fit into its u32 length prefix.

Fields

wire_type: WireType

The affected wire type.

length: usize

The supplied payload length.



Write(Error)

The underlying writer failed.



Read(Error)

The underlying reader failed for a reason other than end of stream.