pub enum CodecError {
InvalidSchema(SchemaError),
TableSchemaMustBeTuple {
found: WireType,
},
Truncated {
context: &'static str,
},
RowTooLarge {
limit: usize,
},
BlobTooLarge {
wire_type: WireType,
length: usize,
limit: usize,
},
ValueDoesNotMatchSchema {
expected: WireType,
actual: &'static str,
},
TupleLength {
expected: usize,
actual: usize,
},
InvalidVariantTag {
wire_type: WireType,
tag: u16,
children: usize,
},
VariantTagTooWide {
wire_type: WireType,
tag: u16,
},
BlobLengthOverflowsU32 {
wire_type: WireType,
length: usize,
},
Write(Error),
Read(Error),
}Expand description
A wire or I/O failure while encoding or decoding Skiff.
Variants
InvalidSchema(SchemaError)
A schema was invalid before a stream was touched.
TableSchemaMustBeTuple
A table format schema did not have the required tuple root.
Truncated
The stream ended after a row had started.
RowTooLarge
One row would decode into more memory than the configured limit.
BlobTooLarge
A declared blob size would exceed the configured resource limit.
Fields
ValueDoesNotMatchSchema
An encoded value did not match its schema node.
Fields
TupleLength
A tuple carried a different number of values than its schema children.
InvalidVariantTag
A variant tag did not select a child in its schema.
Fields
VariantTagTooWide
A repeated-variant value carried a tag wider than the variant supports.
BlobLengthOverflowsU32
A caller supplied a payload that cannot fit into its u32 length prefix.
Write(Error)
The underlying writer failed.
Read(Error)
The underlying reader failed for a reason other than end of stream.